@@ -1,8 +1,13 @@
-# $Id: Index.pm 35 2011-06-17 01:34:42Z stro $
+# $Id: Index.pm 42 2013-06-29 20:44:17Z stro $
 
 package CPAN::SQLite::Index;
 use strict;
 use warnings;
+
+our $VERSION = '0.203';
+
+use English qw/-no_match_vars/;
+
 use CPAN::SQLite::Info;
 use CPAN::SQLite::State;
 use CPAN::SQLite::Populate;
@@ -12,7 +17,6 @@ use File::Basename;
 use File::Path;
 use LWP::Simple qw(getstore is_success);
 
-our $VERSION = '0.202';
 unless ($ENV{CPAN_SQLITE_NO_LOG_FILES}) {
   $ENV{CPAN_SQLITE_DEBUG} = 1;
 }
@@ -55,6 +59,23 @@ sub index {
         $oldout = error_fh($log);
     }
 
+    my $log_cleanup = $ENV{'CPAN_SQLITE_LOG_FILES_CLEANUP'};
+    $log_cleanup = 30 unless defined $log_cleanup;
+    if ($log_cleanup and $log_cleanup =~ /^\d+$/) {
+      if (opendir(my $DIR, $self->{'log_dir'})) {
+        my @files = grep { /cpan_sqlite_log\./ } readdir $DIR;
+        closedir $DIR;
+
+        @files = grep { -C $_ > $log_cleanup } map { catfile($self->{'log_dir'}, $_) } @files;
+
+        if (@files) {
+          $CPAN::FrontEnd->myprint('Cleaning old log files ... ');
+          unlink @files;
+          $CPAN::FrontEnd->myprint("Done.\n");
+        }
+      }
+    }
+
     if ($self->{'update_indices'}) {
         $CPAN::FrontEnd->myprint('Fetching index files ... ');
         if ($self->fetch_cpan_indices()) {
@@ -90,7 +111,7 @@ sub index {
         $CPAN::FrontEnd->mywarn("Failed\n");
         return;
     }
-    
+
     return 1;
 }
 
@@ -127,7 +148,7 @@ sub fetch_info {
   my %wanted = map {$_ => $self->{$_}} qw(CPAN ignore keep_source_where);
   my $info = CPAN::SQLite::Info->new(%wanted);
   $info->fetch_info() or return;
-  my @tables = qw(dists mods auths);
+  my @tables = qw(dists mods auths info);
   my $index;
   foreach my $table(@tables) {
     my $class = __PACKAGE__ . '::' . $table;
@@ -141,8 +162,7 @@ sub fetch_info {
 sub state {
   my $self = shift;
 
-  my %wanted = map {$_ => $self->{$_}} 
-    qw(db_name index setup reindex db_dir);
+  my %wanted = map {$_ => $self->{$_}} qw(db_name index setup reindex db_dir);
   my $state = CPAN::SQLite::State->new(%wanted);
   $state->state() or return;
   $self->{state} = $state;
@@ -151,8 +171,7 @@ sub state {
 
 sub populate {
   my $self = shift;
-  my %wanted = map {$_ => $self->{$_}} 
-    qw(db_name index setup state db_dir);
+  my %wanted = map {$_ => $self->{$_}} qw(db_name index setup state db_dir);
   my $db = CPAN::SQLite::Populate->new(%wanted);
   $db->populate() or return;
   return 1;
@@ -179,8 +198,6 @@ sub DESTROY {
 
 1;
 
-__END__
-
 =head1 NAME
 
 CPAN::SQLite::Index - set up or update database tables.
@@ -224,7 +241,7 @@ Calling
 
 will start the indexing procedure. Various messages
 detailing the progress will written to I<STDOUT>,
-which by default will be captured into a file 
+which by default will be captured into a file
 F<cpan_sqlite_log.dddddddddd>, where the extension
 is the C<time> that the method was invoked. Error messages
 are not captured, and will appear in I<STDERR>.
@@ -235,7 +252,7 @@ The steps of the indexing procedure are as follows.
 
 =item * fetch index data
 
-The necessary CPAN index files 
+The necessary CPAN index files
 F<$CPAN/authors/01mailrc.txt.gz>,
 F<$CPAN/modules/02packages.details.txt.gz>, and
 F<$CPAN/modules/03modlist.data.gz> will be fetched
