@@ -1,11 +1,14 @@
-# $Id: Util.pm 35 2011-06-17 01:34:42Z stro $
+# $Id: Util.pm 42 2013-06-29 20:44:17Z stro $
 
 package CPAN::SQLite::Util;
 use strict;
 use warnings;
-our $VERSION = '0.202';
 
-use base qw(Exporter);
+our $VERSION = '0.203';
+
+use English qw/-no_match_vars/;
+
+use parent 'Exporter';
 our (@EXPORT_OK, %chaps, %modes,
      $table_id, $query_info, $mode_info, $full_id, $dslip);
 @EXPORT_OK = qw(%chaps $repositories %modes
